api

package module
v0.0.0-...-22f813a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

README

tigera/api

This is the location of the Tigera API structures for use in code that wants to use the Tigera API.

How to use

One way is to import the clientset directly and use it. See examples/list-gnp/main.go for some example code.

Adding new APIs

  1. Create a .go file which contains the new type to pkg/apis/<apigroup>/<version>

  2. Add the new type to pkg/apis/<apigroup>/<version>/register.go

  3. Update generated code, including clients, informers, etc.

    make build
    

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AllCRDs

func AllCRDs() ([]*v1.CustomResourceDefinition, error)

AllCRDs loads and returns all embedded v3 CRD definitions.

Types

This section is empty.

Directories

Path Synopsis
examples
list-gnp command
hack
openapi-schema command
openapi-schema dumps the Calico OpenAPI schema as Swagger 2.0 JSON to stdout.
openapi-schema dumps the Calico OpenAPI schema as Swagger 2.0 JSON to stdout.
pkg
apis/usage.tigera.io/v1
+k8s:deepcopy-gen=package,register +groupName=usage.tigera.io
+k8s:deepcopy-gen=package,register +groupName=usage.tigera.io
client/clientset_generated/clientset/fake
This package has the automatically generated fake clientset.
This package has the automatically generated fake clientset.
client/clientset_generated/clientset/scheme
This package contains the scheme of the automatically generated clientset.
This package contains the scheme of the automatically generated clientset.
client/clientset_generated/clientset/typed/projectcalico/v3
This package has the automatically generated typed clients.
This package has the automatically generated typed clients.
client/clientset_generated/clientset/typed/projectcalico/v3/fake
Package fake has the automatically generated clients.
Package fake has the automatically generated clients.

Jump to